
# Tavily MCP Server

An MCP Server for the Tavily API.

## Supported Integrations

- AgentR
- API Key (Coming Soon)
- OAuth (Coming Soon)

## Tools

This is automatically generated from OpenAPI schema for the Tavily API.

## Supported Integrations

This tool can be integrated with any service that supports HTTP requests.

## Tool List

| Tool | Description |
|------|-------------|
| search | Search the web using Tavily's search API |
| validate | Function for validate |



## Usage

- Login to AgentR
- Follow the quickstart guide to setup MCP Server for your client
- Visit Apps Store and enable the Tavily app
- Restart the MCP Server

### Local Development

- Follow the README to test with the local MCP Server
